==> chaosmesh-model-6.3.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PhysicalMachineChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PhysicalMachineChaosStatusFluent<A extends PhysicalMachineChaosStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,ChaosCondition item);
  public A setToConditions(Integer index,ChaosCondition item);
  public A addToConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A addAllToConditions(Collection<ChaosCondition> items);
  public A removeFromConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A removeAllFromConditions(Collection<ChaosCondition> items);
  public A removeMatchingFromConditions(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ChaosCondition> getConditions();
  public List<ChaosCondition> buildConditions();
  public ChaosCondition buildCondition(Integer index);
  public ChaosCondition buildFirstCondition();
  public ChaosCondition buildLastCondition();
  public ChaosCondition buildMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public A withConditions(List<ChaosCondition> conditions);
  public A withConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String reason,String status,String type);
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> addNewCondition();
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> addNewConditionLike(ChaosCondition item);
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,ChaosCondition item);
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> editFirstCondition();
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> editLastCondition();
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExperiment instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExperimentStatus getExperiment();
  public ExperimentStatus buildExperiment();
  public A withExperiment(ExperimentStatus experiment);
  public Boolean hasExperiment();
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> withNewExperiment();
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> editExperiment();
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
  public interface ConditionsNested<N> extends Nested<N>,ChaosConditionFluent<PhysicalMachineChaosStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface ExperimentNested<N> extends Nested<N>,ExperimentStatusFluent<PhysicalMachineChaosStatusFluent.ExperimentNested<N>>{
    public N and();
    public N endExperiment();
    
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PhysicalMachineChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PhysicalMachineChaosStatusFluent<A extends PhysicalMachineChaosStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,ChaosCondition item);
  public A setToConditions(int index,ChaosCondition item);
  public A addToConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A addAllToConditions(Collection<ChaosCondition> items);
  public A removeFromConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A removeAllFromConditions(Collection<ChaosCondition> items);
  public A removeMatchingFromConditions(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ChaosCondition> getConditions();
  public List<ChaosCondition> buildConditions();
  public ChaosCondition buildCondition(int index);
  public ChaosCondition buildFirstCondition();
  public ChaosCondition buildLastCondition();
  public ChaosCondition buildMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public A withConditions(List<ChaosCondition> conditions);
  public A withConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String reason,String status,String type);
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> addNewCondition();
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> addNewConditionLike(ChaosCondition item);
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> setNewConditionLike(int index,ChaosCondition item);
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> editCondition(int index);
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> editFirstCondition();
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> editLastCondition();
  public PhysicalMachineChaosStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExperiment instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExperimentStatus getExperiment();
  public ExperimentStatus buildExperiment();
  public A withExperiment(ExperimentStatus experiment);
  public Boolean hasExperiment();
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> withNewExperiment();
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> editExperiment();
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
  public PhysicalMachineChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
  public interface ConditionsNested<N> extends Nested<N>,ChaosConditionFluent<PhysicalMachineChaosStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface ExperimentNested<N> extends Nested<N>,ExperimentStatusFluent<PhysicalMachineChaosStatusFluent.ExperimentNested<N>>{
    public N and();
    public N endExperiment();
    
  }
  
}
